@@ -22,9 +22,9 @@ pcr.model <- function(X, Y, ncomp, newX)
   }
 
   if (!is.null(newX))
-    list(B=B, XvarExpl=matrix(cumsum(D)[ncomp]/sum(D), ncol=1),
+    list(B=B, XvarExpl=matrix(cumsum(D^2)[ncomp]/sum(huhn$d^2), ncol=1),
          YvarExpl=yve, Ypred=Ypred)
   else
-    list(B=B, XvarExpl=matrix(cumsum(D)[ncomp]/sum(D), ncol=1),
+    list(B=B, XvarExpl=matrix(cumsum(D^2)[ncomp]/sum(huhn$d^2), ncol=1),
          YvarExpl=yve)
 }
